Learn R Programming

outlierensembles (version 0.1.3)

Y: A dataset containing anomaly scores

Description

This dataset contains anomaly scores for the annulus data

Usage

Y

Arguments

Format

A dataframe of 803 rows and 9 columns

Dimension 1

The different anomaly detection methods

Dimension 2

Each column has the anomaly scores from that method for the annulus dataset.