powered by
This dataset contains anomaly scores for the Old Faithful dataset
Yfaithful
A dataframe of 272 rows and 9 columns
The different anomaly detection methods
Each column has the anomaly scores from that method for the old faithful dataset.