powered by
This dataset contains anomaly scores for the annulus data
Y
A dataframe of 803 rows and 9 columns
The different anomaly detection methods
Each column has the anomaly scores from that method for the annulus dataset.